==> open-xchange-usm_7.0.1.orig.tar.bz2: open-xchange-usm-7.0.1/com.openexchange.usm.api/src/com/openexchange/usm/api/datatypes/DateDataType.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.api.datatypes;

import org.json.*;

import com.openexchange.usm.api.session.Session;

/**
 * DataType for fields that store a Date
 * 
 * @author afe
 *
 */
public class DateDataType extends AbstractDataType<Long> {
	public static final String NAME = "Date";

	public String getName() {
		return NAME;
	}

	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
		parent.put(value);
	}

	public Long checkValue(Object o) {
		if (o == null)
			return null;
		if (o instanceof Long)
			return (Long) o;
		if (!(o instanceof Number))
			generateTypeError(o);
		return ((Number) o).longValue();
	}

	public Long extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
		return array.isNull(index) ? null : array.getLong(index);
	}

	public Long extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
		return jsonObject.isNull(field) ? null : jsonObject.getLong(field);
	}

	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
		parent.put(field, (value == null) ? JSONObject.NULL : value);
	}

	//	protected Long convertFromUTCToUser(Session session, Long t) {
	//		if (t == null)
	//			return t;
	//		long result = t + session.getUserTimeZone().getOffset(t);
	//		return result;
	//	}
	//
	//	protected long convertFromUserToUTC(Session session, long t) {
	//		// This may not completely correct, for those times where a switch occurs, we may be off (since getOffset uses UTC, not local time)
	//		long result = t - session.getUserTimeZone().getOffset(t);
	//		return result;
	//	}
}

==> open-xchange-usm_7.4.1.orig.tar.bz2: open-xchange-usm-7.4.1/com.openexchange.usm.api/src/com/openexchange/usm/api/datatypes/DateDataType.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.api.datatypes;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.usm.api.session.Session;

/**
 * DataType for fields that store a Date
 * 
 * @author afe
 *
 */
public class DateDataType extends AbstractDataType<Long> {
	public static final String NAME = "Date";

	public String getName() {
		return NAME;
	}

	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
		parent.put(value);
	}

	public Long checkValue(Object o) {
		if (o == null)
			return null;
		if (o instanceof Long)
			return (Long) o;
		if (!(o instanceof Number))
			generateTypeError(o);
		return ((Number) o).longValue();
	}

	public Long extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
		return array.isNull(index) ? null : array.getLong(index);
	}

	public Long extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
		return jsonObject.isNull(field) ? null : jsonObject.getLong(field);
	}

	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
		parent.put(field, (value == null) ? JSONObject.NULL : value);
	}

	//	protected Long convertFromUTCToUser(Session session, Long t) {
	//		if (t == null)
	//			return t;
	//		long result = t + session.getUserTimeZone().getOffset(t);
	//		return result;
	//	}
	//
	//	protected long convertFromUserToUTC(Session session, long t) {
	//		// This may not completely correct, for those times where a switch occurs, we may be off (since getOffset uses UTC, not local time)
	//		long result = t - session.getUserTimeZone().getOffset(t);
	//		return result;
	//	}
}
